@@ -56,12 +56,24 @@ def _PrintAndConfirmWarningMessage(args, database_version):
   continue_msg = None
 
   insights_query_length_changed = (
-      'insights_config_query_string_length' in args and
-      args.insights_config_query_string_length is not None)
+      'insights_config_query_string_length' in args
+      and args.insights_config_query_string_length is not None
+  )
+
+  active_directory_config_changed = any([
+      args.active_directory_domain is not None,
+      args.clear_active_directory is not None,
+      args.clear_active_directory_dns_servers is not None,
+      args.active_directory_dns_servers is not None,
+      args.active_directory_secret_manager_key is not None,
+      args.active_directory_organizational_unit is not None,
+      args.active_directory_mode is not None,
+  ])
+
   if any([
       args.tier,
       args.enable_database_replication is not None,
-      args.active_directory_domain is not None,
+      active_directory_config_changed,
       insights_query_length_changed,
   ]):
     continue_msg = ('WARNING: This patch modifies a value that requires '
@@ -170,6 +182,8 @@ def _GetConfirmedClearedFields(args, patch_instance, original_instance):
     cleared_fields.append('settings.uncMappings')
   if args.clear_active_directory_dns_servers:
     cleared_fields.append('settings.activeDirectoryConfig.dnsServers')
+  if args.clear_active_directory:
+    cleared_fields.append('settings.activeDirectoryConfig')
 
   log.status.write(
       'The following message will be used for the patch API method.\n'
@@ -340,12 +354,18 @@ def AddBaseArgs(parser):
   flags.AddActiveDirectoryOrganizationalUnit(parser, hidden=True)
   flags.AddActiveDirectoryDNSServers(parser, hidden=True)
   flags.ClearActiveDirectoryDNSServers(parser, hidden=True)
+  flags.AddClearActiveDirectory(parser, hidden=True)
   flags.AddFinalBackup(parser)
   flags.AddFinalbackupRetentionDays(parser)
   flags.AddEnableConnectionPooling(parser)
   connection_pool_flags_group = parser.add_mutually_exclusive_group()
   flags.AddConnectionPoolFlags(connection_pool_flags_group)
   flags.AddClearConnectionPoolFlags(connection_pool_flags_group)
+  psc_update_auto_connections_group = parser.add_mutually_exclusive_group()
+  flags.AddPscAutoConnections(psc_update_auto_connections_group)
+  flags.AddClearPscAutoConnections(psc_update_auto_connections_group)
+  flags.AddServerCaMode(parser)
+  flags.AddServerCaPool(parser)
 
 
 def AddBetaArgs(parser):
@@ -354,14 +374,9 @@ def AddBetaArgs(parser):
   flags.AddAllocatedIpRangeName(parser)
   labels_util.AddUpdateLabelsFlags(parser, enable_clear=True)
   flags.AddReplicationLagMaxSecondsForRecreate(parser)
-  psc_update_auto_connections_group = parser.add_mutually_exclusive_group()
-  flags.AddPscAutoConnections(psc_update_auto_connections_group)
-  flags.AddClearPscAutoConnections(psc_update_auto_connections_group)
   flags.AddReconcilePsaNetworking(parser)
   flags.AddEnableAcceleratedReplicaMode(parser)
   flags.AddEnableAutoUpgrade(parser)
-  flags.AddServerCaMode(parser, hidden=True)
-  flags.AddServerCaPool(parser, hidden=True)
   unc_mappings_group = parser.add_mutually_exclusive_group(hidden=True)
   flags.AddUncMappings(unc_mappings_group)
   flags.AddClearUncMappings(unc_mappings_group)
